@@ -6,20 +6,19 @@
 maketri2 <- function(y,D,R,k) {
   m = nrow(D)
   n = ncol(D)
-  
-  a = .C("maketri2",
+
+  a = .C(C_maketri2,
     y=as.double(y),
     D=as.double(D),
     R=as.double(R),
     m=as.integer(m),
     n=as.integer(n),
     k=as.integer(k),
-    dup=FALSE,
-    package="genlasso")
+    PACKAGE="genlasso")
 
   y = a$y
   D = matrix(a$D,nrow=m)
   R = matrix(a$R,nrow=m)
-  
+
   return(list(y=y,D=D,R=R))
 }
