@@ -20,7 +20,7 @@ maketri4 <- function(y,D1,D2,Q1,Q2,R,q,k) {
   # The full R
   if (m2>n) R = rbind(R,matrix(0,m2-n,n))
 
-  a = .C("maketri4",
+  a = .C(C_maketri4,
     y=as.double(y),
     D=as.double(D),
     Q=as.double(Q),
@@ -30,8 +30,7 @@ maketri4 <- function(y,D1,D2,Q1,Q2,R,q,k) {
     n=as.integer(n),
     q=as.integer(q),
     k=as.integer(k-1),
-    dup=FALSE,
-    package="genlasso")
+    PACKAGE="genlasso")
 
   y = a$y
   D = matrix(a$D,nrow=m1)
@@ -45,6 +44,6 @@ maketri4 <- function(y,D1,D2,Q1,Q2,R,q,k) {
   Q1 = Q[,Seq(1,r),drop=FALSE]
   Q2 = Q[,Seq(r+1,m2),drop=FALSE]
   R = R[Seq(1,r),,drop=FALSE]
-  
+
   return(list(y=y,D1=D1,D2=D2,Q1=Q1,Q2=Q2,R=R))
 }
